#ifndef MAP_H_INCLUDED_
#define MAP_H_INCLUDED_

// MAP dialogue handling primitives

#define MAP_OPEN_REQ 100
#define MAP_OPEN_IND 101
#define MAP_OPEN_RES 102
#define MAP_OPEN_CNF 103
#define MAP_CLOSE_REQ 104
#define MAP_CLOSE_IND 105
#define MAP_DELIMITER 106
#define MAP_U_ABORT_REQ 107
#define MAP_U_ABORT_IND 108
#define MAP_P_ABORT_IND 109
#define MAP_NOTICE 110

// MAP service handling primitives

#define MAP_CANCEL_LOCATION_REQ 120
#define MAP_CANCEL_LOCATION_IND 121
#define MAP_CANCEL_LOCATION_RES 122
#define MAP_CANCEL_LOCATION_CNF 123
#define MAP_PURGE_MS_REQ 124
#define MAP_PURGE_MS_IND 125
#define MAP_PURGE_MS_RES 126
#define MAP_PURGE_MS_CNF 127
#define MAP_UPDATE_GPRS_LOCATION_REQ 128
#define MAP_UPDATE_GPRS_LOCATION_IND 129
#define MAP_UPDATE_GPRS_LOCATION_RES 130
#define MAP_UPDATE_GPRS_LOCATION_CNF 131
#define MAP_SEND_AUTHENTICATION_INFO_REQ 132
#define MAP_SEND_AUTHENTICATION_INFO_IND 133
#define MAP_SEND_AUTHENTICATION_INFO_RES 134
#define MAP_SEND_AUTHENTICATION_INFO_CNF 135
#define MAP_INSERT_SUBSCRIBER_DATA_REQ 136
#define MAP_INSERT_SUBSCRIBER_DATA_IND 137
#define MAP_INSERT_SUBSCRIBER_DATA_RES 138
#define MAP_INSERT_SUBSCRIBER_DATA_CNF 139
#define MAP_DELETE_SUBSCRIBER_DATA_REQ 140
#define MAP_DELETE_SUBSCRIBER_DATA_IND 141
#define MAP_DELETE_SUBSCRIBER_DATA_RES 142
#define MAP_DELETE_SUBSCRIBER_DATA_CNF 143
#define MAP_RESET_REQ 144
#define MAP_RESET_IND 145
#define MAP_SEND_ROUTING_INFO_FOR_GPRS_REQ 146
#define MAP_SEND_ROUTING_INFO_FOR_GPRS_IND 147
#define MAP_SEND_ROUTING_INFO_FOR_GPRS_RES 148
#define MAP_SEND_ROUTING_INFO_FOR_GPRS_CNF 149
#define MAP_FAILURE_REPORT_REQ 150
#define MAP_FAILURE_REPORT_IND 151
#define MAP_FAILURE_REPORT_RES 152
#define MAP_FAILURE_REPORT_CNF 153
#define MAP_NOTE_MS_PRESENT_FOR_GPRS_REQ 154
#define MAP_NOTE_MS_PRESENT_FOR_GPRS_IND 155
#define MAP_NOTE_MS_PRESENT_FOR_GPRS_RES 156
#define MAP_NOTE_MS_PRESENT_FOR_GPRS_CNF 157

#define MAP_TERMINATE_RSM 160
#define MAP_TERMINATE_PSM 161

#define MAP_SPECIFIC_REQ ( \
messageType == MAP_CANCEL_LOCATION_REQ || \
messageType == MAP_PURGE_MS_REQ || \
messageType == MAP_UPDATE_GPRS_LOCATION_REQ || \
messageType == MAP_SEND_AUTHENTICATION_INFO_REQ || \
messageType == MAP_INSERT_SUBSCRIBER_DATA_REQ || \
messageType == MAP_DELETE_SUBSCRIBER_DATA_REQ || \
messageType == MAP_RESET_REQ || \
messageType == MAP_SEND_ROUTING_INFO_FOR_GPRS_REQ || \
messageType == MAP_FAILURE_REPORT_REQ || \
messageType == MAP_NOTE_MS_PRESENT_FOR_GPRS_REQ )

#define MAP_SPECIFIC_RES ( \
messageType == MAP_CANCEL_LOCATION_RES || \
messageType == MAP_PURGE_MS_RES || \
messageType == MAP_UPDATE_GPRS_LOCATION_RES || \
messageType == MAP_SEND_AUTHENTICATION_INFO_RES || \
messageType == MAP_INSERT_SUBSCRIBER_DATA_RES || \
messageType == MAP_DELETE_SUBSCRIBER_DATA_RES || \
messageType == MAP_SEND_ROUTING_INFO_FOR_GPRS_RES || \
messageType == MAP_FAILURE_REPORT_RES || \
messageType == MAP_NOTE_MS_PRESENT_FOR_GPRS_RES )


// TCAP dialogue handling primitives

#define TC_BEGIN_REQ 180
#define TC_BEGIN_IND 180
#define TC_CONTINUE_REQ 182
#define TC_CONTINUE_IND 182
#define TC_END_REQ 184
#define TC_END_IND 184
#define TC_U_ABORT_REQ 186
#define TC_U_ABORT_IND 186
#define TC_P_ABORT_IND 188
#define TC_NOTICE_IND 189

// TCAP component handling primitives

#define TC_INVOKE_REQ 190
#define TC_INVOKE_IND 190
#define TC_RESULT_L_REQ 192
#define TC_RESULT_L_IND 192
#define TC_RESULT_NL_REQ 194
#define TC_RESULT_NL_IND 194
#define TC_U_ERROR_REQ 196
#define TC_U_ERROR_IND 196
#define TC_L_CANCEL_IND 198
#define TC_U_CANCEL_REQ 199
#define TC_L_REJECT_IND 200
#define TC_R_REJECT_IND 201
#define TC_U_REJECT_REQ 202
#define TC_U_REJECT_IND 202
#define TC_TIMER_RESET_IND 203

// Application contexts for MAP

#define locationCancellationContext 2
#define infoRetrivalContext 14
#define msPurgingContext 27
#define resetContext 10
#define gprsLocationUpdateContext 32
#define subscriberDataMngtContext 16
#define gprsNotifyContext 35
#define gprsLocationInfoRetrivalContext 33
#define failureReportContext 34

#define contextExist ( \
appContext == locationCancellationContext || \
appContext == infoRetrivalContext || \
appContext == msPurgingContext || \
appContext == resetContext || \
appContext == gprsLocationUpdateContext || \
appContext == subscriberDataMngtContext || \
appContext == gprsNotifyContext || \
appContext == gprsLocationInfoRetrivalContext || \
appContext == failureReportContext )

#define operationExist ( \
operation == MAP_CANCEL_LOCATION_REQ || \
operation == MAP_PURGE_MS_REQ || \ 
operation == MAP_UPDATE_GPRS_LOCATION_REQ || \
operation == MAP_SEND_AUTHENTICATION_INFO_REQ || \ 
operation == MAP_INSERT_SUBSCRIBER_DATA_REQ || \
operation == MAP_DELETE_SUBSCRIBER_DATA_REQ || \ 
operation == MAP_RESET_REQ || \
operation == MAP_SEND_ROUTING_INFO_FOR_GPRS_REQ || \ 
operation == MAP_FAILURE_REPORT_REQ || \ 
operation == MAP_NOTE_MS_PRESENT_FOR_GPRS_REQ)


// results, errors and abort reasons

#define ABNORMAL_MAP_DIALOGUE 1
#define DIALOGUE_ACCEPTED 2
#define DIALOGUE_REFUSED 3
#define USER_SPECIFIC 4
#define AC_NOT_SUPPORTED 5
#define UNRECOGNIZED_OPERATION 6

// termination type for TCAP

#define PREARRANGED 1
#define BASIC 2
#define ABORT 3

#endif
