/* oms_dist_support.h					*/
/* OPNET Model Support package			*/
/* Distribution Modeling sub-package	*/

/****************************************/
/*  	Copyright (c) 1987 - 2002       */
/*		by OPNET Technologies, Inc.		*/
/*       (A Delaware Corporation)       */
/*    7255 Woodmont Av., Suite 250      */
/*     Bethesda, MD 20814, U.S.A.       */
/*       All Rights Reserved.           */
/****************************************/

#ifndef _oms_dist_support_h_
#define _oms_dist_support_h_

/***** Includes *****/

#include "opnet.h"
#include <math.h>

#if defined (__cplusplus)
extern "C" {
#endif

#ifndef OMSC_EXPORT
#define OMSC_EXPORT
#endif

/***** Data Structures	*****/

/* Data structures part of the distribution loading and outcome.	*/

typedef double				(* OmsT_DistOutcome_Proc) (double, double);
typedef double				(* OmsT_FileOutcome_Proc) (void*, int*);

typedef struct
	{
	OmsT_DistOutcome_Proc	dist_outcome_proc;	/* Function to be used to get outcomes.	*/			
	double 					dist_arg0;			/* First argument to the distribution.  */
	double					dist_arg1;			/* Second argument to the distribution. */
	int						num_references;		/* Number of references made to this    */
												/* distribution handle.                 */
	} OmsT_Distribution_Params;

typedef struct
	{
	OmsT_FileOutcome_Proc	file_outcome_proc;	/* Function to be used to get outcomes.	*/			
	double*					file_outcome_ptr;	/* Table to store each outcome.			*/
	int						num_outcomes;		/* Total number of entries in the file.	*/
	int						current_index;		/* Index of the last read value.		*/
	} OmsT_Dist_File_Params;

typedef union
	{
	OmsT_Distribution_Params 	dist_params;	/* Structure holding the distribution	*/
												/* arguments and the number of refs.	*/
												/* of that distribution.				*/
	OmsT_Dist_File_Params		file_params;	/* Structure holding the file list ptr	*/
												/* and the current element index in the	*/
												/* list.								*/
	} OmsT_Dist_Info;

typedef struct
	{
	char					dist_name [64];		/* Name of the loaded distribution.		*/
	Distribution*			distribution_ptr;	/* Distribution pointer.				*/
	OmsT_Dist_Info 			dist_info;			/* A union of the dist parameters struct*/
												/* and the file parameters structure.	*/
	} OmsT_Distribution;

/* Distribution Handle used by calling functions to load	*/
/* and generate from loaded distributions.					*/
typedef OmsT_Distribution*	OmsT_Dist_Handle;

/***** Function Prototypes *****/

OMSC_EXPORT OmsT_Dist_Handle	oms_dist_load_from_string (const char* dist_string);
OMSC_EXPORT OmsT_Dist_Handle    oms_dist_scaled_load_from_string (const char* dist_string, double scaling_factor);
OMSC_EXPORT void				oms_dist_parameters_get (char* dist_arg_string, double* first_argument_ptr, double* second_argument_ptr);
OMSC_EXPORT OmsT_Dist_Handle	oms_dist_load (const char* dist_name, double dist_arg0, double dist_arg1);
OMSC_EXPORT OmsT_Dist_Handle 	oms_dist_load_from_file (const char* dist_name, const char *file_name);
OMSC_EXPORT double				oms_dist_outcome (OmsT_Distribution* dist_ptr);
OMSC_EXPORT double 				oms_dist_scripted_file_outcome (OmsT_Dist_Handle dist_handle, int* current_index);
OMSC_EXPORT void				oms_dist_destroy (OmsT_Distribution* dist_ptr);

OMSC_EXPORT double				oms_dist_mean_compute (OmsT_Dist_Handle dist_handle);
OMSC_EXPORT double				oms_dist_variance_compute (OmsT_Dist_Handle dist_handle);
OMSC_EXPORT void				oms_dist_lognormal_parameters_get (double mean, double variance, 
						double* normal_mean_ptr, double* normal_sdev_ptr);
OMSC_EXPORT double				oms_dist_normal_box_mueller_outcome (double mean, double stdev);
OMSC_EXPORT double				oms_dist_lognormal_from_normal_outcome (double normal_outcome);
OMSC_EXPORT double				oms_dist_exponential_outcome (double expon_mean);

OMSC_EXPORT double				oms_dist_pareto_outcome (double location_parameter, double shape_parameter);
OMSC_EXPORT double				oms_dist_smoothed_pareto_outcome (double location_parameter, double shape_parameter);
OMSC_EXPORT double				oms_dist_smoothed_pareto_first_outcome (double location_parameter, double shape_parameter);

/* Distribution clipping functions */
OMSC_EXPORT double				oms_dist_positive_outcome (OmsT_Dist_Handle dist_handle);
OMSC_EXPORT double				oms_dist_nonnegative_outcome (OmsT_Dist_Handle dist_handle);


#if defined (__cplusplus)
} /* end of 'extern "C" {' */
#endif

#endif /* for _oms_dist_support_h_ */

